# indibase

INDI Base Client implementation in pure python. It implements the public
functions defined in INDI:BaseClientQt Class Reference:

http://www.indilib.org/api/classINDI_1_1BaseClientQt.html

There might be some alternative mor pythonic methods to do the same, but
it is open to you, what you would like to use. Basically the results
should be identically.

Please use it at you own risk.

Michel